@@ -1,10 +1,11 @@
 /*
     Gstat, a program for geostatistical modelling, prediction and simulation
-    Copyright 1992, 2003 (C) Edzer J. Pebesma
+    Copyright 1992, 2011 (C) Edzer Pebesma
 
-    Edzer J. Pebesma, e.pebesma@geo.uu.nl
-    Department of physical geography, Utrecht University
-    P.O. Box 80.115, 3508 TC Utrecht, The Netherlands
+    Edzer Pebesma, edzer.pebesma@uni-muenster.de
+	Institute for Geoinformatics (ifgi), University of Münster 
+	Weseler Straße 253, 48151 Münster, Germany. Phone: +49 251 
+	8333081, Fax: +49 251 8339763  http://ifgi.uni-muenster.de 
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -168,7 +169,7 @@ void gstat_clo_error(char *f, int l, enum Gstat_errno err, int a) {
 /* message() calls for messages preceding a call to ErrMsg() */
 void message(char *fmt, ...) {
 	va_list args;
-	char *buf = NULL;
+	/* char *buf = NULL; */
 
 	va_start(args, fmt);
 #ifdef HAVE_VSNPRINTF
@@ -177,7 +178,7 @@ void message(char *fmt, ...) {
 	vsprintf(error_prefix->str, fmt, args);
 #endif
 	va_end(args);
-	buf = NULL;
+	/* buf = NULL; */
 }
 
 /* print a warning message to string, and call warning message handler */
